pub struct IssuedToken {
pub token_id: String,
pub credential_name: String,
pub issued_to: Pid,
pub issued_at: DateTime<Utc>,
pub expires_at: DateTime<Utc>,
pub scope: Vec<String>,
}Expand description
A scoped, time-limited token issued to an agent.
Fields
token_id: StringUnique token identifier.
credential_name: StringName of the credential this token grants access to.
issued_to: PidPID of the agent the token was issued to.
issued_at: DateTime<Utc>When the token was issued.
expires_at: DateTime<Utc>When the token expires.
scope: Vec<String>Scoped operations this token permits.
Implementations
Sourceimpl IssuedToken
impl IssuedToken
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Check whether the token has expired.