#[non_exhaustive]pub enum IpcScope {
All,
ParentOnly,
Restricted(Vec<u64>),
Topic(Vec<String>),
None,
}Expand description
IPC scope defining which message targets an agent may communicate with.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
All
Agent may communicate with all other agents.
ParentOnly
Agent may only communicate with its parent.
Restricted(Vec<u64>)
Agent may communicate with a specified set of PIDs.
Topic(Vec<String>)
Agent may only publish/subscribe to specified topics (no direct PID messaging).
None
Agent may not send IPC messages.