pub type NodeId = u64;Expand description
Numeric identifier for causal graph nodes.
This is local to the causal module and distinct from
crate::cluster::NodeId which is a String.
pub type NodeId = u64;Numeric identifier for causal graph nodes.
This is local to the causal module and distinct from
crate::cluster::NodeId which is a String.