pub struct CapabilityGate { /* private fields */ }Expand description
Gate backend wrapping the existing CapabilityChecker.
Always returns Permit or Deny (never Defer). This is the
default gate used when no external gate crate is enabled.
Implementations
Sourceimpl CapabilityGate
impl CapabilityGate
Sourcepub fn new(process_table: Arc<ProcessTable>) -> Self
pub fn new(process_table: Arc<ProcessTable>) -> Self
Create a capability gate backed by the given process table.