pub struct ImpulseQueue { /* private fields */ }Expand description
Thread-safe queue of Impulse events awaiting consumption.
Implementations
Sourceimpl ImpulseQueue
impl ImpulseQueue
Sourcepub fn emit(
&self,
source_structure: u8,
source_node: [u8; 32],
target_structure: u8,
impulse_type: ImpulseType,
payload: Value,
hlc_timestamp: u64,
) -> u64
pub fn emit( &self, source_structure: u8, source_node: [u8; 32], target_structure: u8, impulse_type: ImpulseType, payload: Value, hlc_timestamp: u64, ) -> u64
Enqueue a new impulse and return its assigned id.
Sourcepub fn drain_ready(&self) -> Vec<Impulse>
pub fn drain_ready(&self) -> Vec<Impulse>
Drain all unacknowledged impulses, returning them sorted by
hlc_timestamp (ascending). Acknowledged impulses are discarded.
Sourcepub fn pending_count(&self) -> usize
pub fn pending_count(&self) -> usize
Count of impulses that have not yet been acknowledged.