load_all

Function load_all 

pub fn load_all(
    config: &PersistenceConfig,
) -> Result<(CausalGraph, HnswService), Error>
Restore all kernel state from the configured data directory.

Components that have no saved state are returned as fresh instances.