pub fn load_causal_graph(
config: &PersistenceConfig,
) -> Result<CausalGraph, Error>Expand description
Load a causal graph from the configured data directory.
Returns a new empty graph if the file does not exist.
pub fn load_causal_graph(
config: &PersistenceConfig,
) -> Result<CausalGraph, Error>Load a causal graph from the configured data directory.
Returns a new empty graph if the file does not exist.