pub fn save_all(
config: &PersistenceConfig,
graph: &CausalGraph,
hnsw: &HnswService,
) -> Result<(), Error>Expand description
Save all kernel state to the configured data directory.
pub fn save_all(
config: &PersistenceConfig,
graph: &CausalGraph,
hnsw: &HnswService,
) -> Result<(), Error>Save all kernel state to the configured data directory.