pub fn diff_models(a: &ExportedModel, b: &ExportedModel) -> ModelDiffExpand description
Compare two exported models and produce a structured diff.
pub fn diff_models(a: &ExportedModel, b: &ExportedModel) -> ModelDiffCompare two exported models and produce a structured diff.