pub struct TickHistory { /* private fields */ }Expand description
Ring-buffer of recent tick results for analysis.
Implementations
Sourceimpl TickHistory
impl TickHistory
Sourcepub fn record(&mut self, result: CognitiveTickResult)
pub fn record(&mut self, result: CognitiveTickResult)
Record a tick result, evicting the oldest if at capacity.
Sourcepub fn changes_per_minute(&self) -> f64
pub fn changes_per_minute(&self) -> f64
Compute the average changes per minute based on recorded ticks.
Uses total elapsed time and total change events to derive rate.
Sourcepub fn avg_budget_usage(&self) -> f64
pub fn avg_budget_usage(&self) -> f64
Compute average budget usage ratio (elapsed / budget).
Sourcepub fn idle_ticks(&self) -> usize
pub fn idle_ticks(&self) -> usize
Count consecutive idle ticks (no changes) at the tail.
Sourcepub fn all(&self) -> &VecDeque<CognitiveTickResult>
pub fn all(&self) -> &VecDeque<CognitiveTickResult>
All recorded tick results.